@@ -51,7 +51,8 @@ def _get_page_titles(artist, title):
     for title in content["query"]["search"]:
         titles.append(title["title"])
     
-    return titles
+    titles.append("%s:%s" %(artist.title(), title.title()))
+    return set(titles)
 
 def _get_lyrics(artist, title):
     
